@@ -66,7 +66,7 @@ diamond_collector = run(images=images,
                         get_image_description=False,
                         detect_faces=False,
                         get_object_detection=False,
-                        is_augment_data=True,
+                        is_augment_data=False,
                         image_augmentation_info=ImagesAugmentationInfo(aug_prop=0.1),
                         is_train_model=True, image_models=image_models,
                         is_post_model_analysis=True,
